/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include <stdio.h>
void prheader( routine )

	char *	routine;

{
	printf("#include <stdio.h>\n");
	printf("#include <stdlib.h>\n");
	printf("#include <unistd.h>\n");
	printf("#include <string.h>\n");
	printf("#include <sisio.h>\n\n");
	printf(
"void %s( inbuf, inlen, outbuf, outlen )\n\
\n\
	char *	inbuf;\n\
	int *	inlen;\n\
	char *	outbuf;\n\
	int *	outlen;\n\
\n\
{\n\
	int	start, number, length, perword, ier;\n\
\n",
		routine );
}
